"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextlintKernelDescriptor = void 0;
const DescriptorsFactory_1 = require("./DescriptorsFactory");
class TextlintKernelDescriptor {
    constructor(args) {
        this.args = args;
        this.rule = DescriptorsFactory_1.createTextlintRuleDescriptors(args.rules);
        this.filterRule = DescriptorsFactory_1.createTextlintFilterRuleDescriptors(args.filterRules);
        this.plugin = DescriptorsFactory_1.createTextlintPluginDescriptors(args.plugins);
    }
    /**
     * Return available extensions of plugins
     */
    get availableExtensions() {
        return this.plugin.availableExtensions;
    }
    /**
     * Merge constructor args and partialArgs
     * It shallow merge partialArgs.
     * It means that overwrite root properties by partialArgs.
     */
    shallowMerge(partialArgs) {
        return new TextlintKernelDescriptor(Object.assign(Object.assign({}, this.args), partialArgs));
    }
    /**
     * find PluginDescriptor with extension.
     * This is forward match.
     *
     * If following config of textlint, this method prefer to select MarkdownA for markdown.
     *
     * {
     *     "plugins": [MarkdownA, MarkdownB]
     * }
     */
    findPluginDescriptorWithExt(ext) {
        return this.plugin.findPluginDescriptorWithExt(ext);
    }
}
exports.TextlintKernelDescriptor = TextlintKernelDescriptor;
//# sourceMappingURL=TextlintKernelDescriptor.js.map