// LICENSE : MIT
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.through = exports.filterWarningMessages = void 0;
const TextlintRuleSeverityLevelKeys_1 = require("../context/TextlintRuleSeverityLevelKeys");
/**
 * Filter messages by their severity.
 * @param {TextlintMessage[]} messages
 * @returns {TextlintMessage[]} filtered messages
 */
function filterWarningMessages(messages = []) {
    return messages.filter((message) => {
        return message.severity === TextlintRuleSeverityLevelKeys_1.TextlintRuleSeverityLevelKeys.error;
    });
}
exports.filterWarningMessages = filterWarningMessages;
/**
 * Pass through all messages.
 * @param {TextlintMessage[]} messages
 * @returns {TextlintMessage[]}
 */
function through(messages = []) {
    return messages;
}
exports.through = through;
/**
 * Create message filter by config.quiet.
 * @param {Config} config
 * @returns {Function} filter function for messages
 */
function createSeverityFilter(config) {
    if (config.quiet) {
        return filterWarningMessages;
    }
    else {
        return through;
    }
}
exports.default = createSeverityFilter;
//# sourceMappingURL=filter-severity-process.js.map