import { TextlintKernelFilterRule } from "../textlint-kernel-interface";
import { Descriptor } from "./Descriptor";
import type { TextlintFilterRuleOptions, TextlintFilterRuleReporter } from "@textlint/types";
/**
 * Textlint Rule Descriptor.
 * It handle RuleCreator and RuleOption.
 */
export declare class TextlintFilterRuleDescriptor implements Descriptor<TextlintKernelFilterRule> {
    private kernelFilterRule;
    constructor(kernelFilterRule: TextlintKernelFilterRule);
    get id(): string;
    get rule(): TextlintFilterRuleReporter;
    /**
     * Return true if this rule is enabled.
     */
    get enabled(): boolean;
    /**
     * Return filter function
     * You should check hasLiner before call this.
     */
    get filter(): TextlintFilterRuleReporter;
    /**
     * Return normalized rule option object.
     * If the rule have not option, return `true` by default.
     */
    get normalizedOptions(): TextlintFilterRuleOptions;
    get rawOptions(): undefined | boolean | TextlintFilterRuleOptions;
    /**
     * Return true if descriptor is same
     */
    equals(descriptor: this): boolean;
    toKernel(): TextlintKernelFilterRule;
}
