// LICENSE : MIT
"use strict";
import { getFilter } from "./rule-creator-helper";
import deepEqual from "deep-equal";
/**
 * Textlint Rule Descriptor.
 * It handle RuleCreator and RuleOption.
 */
export class TextlintFilterRuleDescriptor {
    constructor(kernelFilterRule) {
        this.kernelFilterRule = kernelFilterRule;
    }
    get id() {
        return this.kernelFilterRule.ruleId;
    }
    get rule() {
        return this.kernelFilterRule.rule;
    }
    /**
     * Return true if this rule is enabled.
     */
    get enabled() {
        return this.rawOptions !== false;
    }
    /**
     * Return filter function
     * You should check hasLiner before call this.
     */
    get filter() {
        return getFilter(this.rule);
    }
    /**
     * Return normalized rule option object.
     * If the rule have not option, return `true` by default.
     */
    get normalizedOptions() {
        // default: { ruleName: true }
        const DefaultRuleConfigValue = {};
        if (typeof this.kernelFilterRule.options === "boolean" || this.kernelFilterRule.options === undefined) {
            return DefaultRuleConfigValue;
        }
        else {
            return this.kernelFilterRule.options;
        }
    }
    get rawOptions() {
        return this.kernelFilterRule.options;
    }
    /**
     * Return true if descriptor is same
     */
    equals(descriptor) {
        return (this.rule === descriptor.rule &&
            deepEqual(this.normalizedOptions, descriptor.normalizedOptions, {
                strict: true
            }));
    }
    toKernel() {
        return this.kernelFilterRule;
    }
}
//# sourceMappingURL=TextlintFilterRuleDescriptor.js.map